@@ -1,15 +1,25 @@
 GEOmap.breakline<-function(Z, ww)
 {
-  ########   ww is a list of locations where there are
+  ########   ww is a vector of locations where there are
   #######   NA
   
   nww = length(ww)
 
+  if(length(Z$x)<0)
+    {
+      x = Z[[1]]
+      y = Z[[2]]
+    }
+  else
+    {
+           x = Z$x
+           y = Z$y
+    }
 
   newx = list()
   newy = list()
 
-  if(nww<1) return(list(newx=Z$x, newy=Z$y) )
+  if(nww<1) return(list(newx=x, newy=y) )
 
   ## ww = c(0, ww, length(Z$x)+1)
 ####  build up a set of strokes separated by NA's
@@ -21,16 +31,16 @@ GEOmap.breakline<-function(Z, ww)
       i2 = (ww[i])
 
       
-      newx[[i]] = Z$x[j:i2]
-      newy[[i]] =  Z$y[j:i2]
+      newx[[i]] = x[j:i2]
+      newy[[i]] =  y[j:i2]
       j = ww[i]+1
     }
 
-  i2 = length(Z$x)
+  i2 = length(x)
   j=ww[i]+1
   i = i+1
-  newx[[i]] = Z$x[j:i2]
-  newy[[i]] = Z$y[j:i2]
+  newx[[i]] = x[j:i2]
+  newy[[i]] = y[j:i2]
 
 
   return(list(newx=newx, newy=newy))
